#!/usr/bin/env python

# specify versions as version number, optionally followed by
# '-SNAPSHOT' for a snapshot version
import sys
import subprocess

def runAndPrint(cmd):
    print cmd
    subprocess.check_output(cmd, shell=True)

oldVersion = sys.argv[1]
newVersion = sys.argv[2]

print oldVersion + " --> " + newVersion

oldVersion = oldVersion.replace(".", "\.")
newVersion = newVersion.replace(".", "\.")

runAndPrint("mvn clean -q")

runAndPrint("find -E ./ -regex \".*(pom|mvncentral)\.xml\" | xargs -n 1 perl -pi -e \'s/" + oldVersion + "/" + newVersion + "/g\'")

runAndPrint("perl -pi -e \'s/" + oldVersion + "/" + newVersion + "/g\' build.gradle")

oldIsSnapshot = oldVersion.endswith("SNAPSHOT")
newIsSnapShot = newVersion.endswith("SNAPSHOT")

bundleOld = oldVersion if not oldIsSnapshot else oldVersion.replace("-SNAPSHOT","\.qualifier")
bundleNew = newVersion if not newIsSnapShot else newVersion.replace("-SNAPSHOT","\.qualifier")

runAndPrint("find -E ./ -regex \".*(MANIFEST\.MF|feature\.xml)\" | xargs -n 1 perl -pi -e \'s/" + bundleOld + "/" + bundleNew + "/g\'")

print "done"
    




#!/usr/bin/env python

# script to build jars for maven central
import sys
import subprocess
import os

# action should be either 'install' (for local test)
# or 'deploy' (for deployment to maven central).
# if current version is SNAPSHOT, will only be deployed
# to sonatype's staging servers.  otherwise, will be
# deployed to maven central
action = sys.argv[1]

# projects for which we should build jars, in order
# will be prefixed with 'com.ibm.wala.'
projects = [
    "util",
    "shrike",
    "core",
    "cast",
    "cast.java",
    "cast.java.ecj",
    "cast.js",
    "cast.js.rhino",
    "dalvik",
    "scandroid"
    ]

for proj in projects:
    full_proj = "com.ibm.wala." + proj
    print(full_proj)
    os.chdir(full_proj)
    mvnCmd = "mvn -f mvncentral.xml clean " + action
    try:
        subprocess.check_output(mvnCmd, shell=True)
    except subprocess.CalledProcessError as e:
        print("OUTPUT")
        print(e.output)
        raise
    os.chdir("..")    

